@@ -1,11 +1,13 @@
 package ChainedActionsApp;
 use Moose;
-use namespace::autoclean;
+use TestLogger;
 
 use Catalyst::Runtime 5.80;
 
 use Catalyst qw//;
 
+use namespace::clean -except => [ 'meta' ];
+
 extends 'Catalyst';
 
 our $VERSION = "0.01";
@@ -16,6 +18,8 @@ __PACKAGE__->config(
   disable_component_regex_fallback => 1,
 );
 
+__PACKAGE__->log(TestLogger->new);
+
 __PACKAGE__->setup;
 
 1;
